/* Generated file */
extern const GdkPixdata viking_pixbuf;
extern const GdkPixdata bing_maps_pixbuf;
extern const GdkPixdata addtr_18_pixbuf;
extern const GdkPixdata begintr_18_pixbuf;
extern const GdkPixdata addwp_18_pixbuf;
extern const GdkPixdata edtr_18_pixbuf;
extern const GdkPixdata edwp_18_pixbuf;
extern const GdkPixdata geomove_18_pixbuf;
extern const GdkPixdata geozoom_18_pixbuf;
extern const GdkPixdata mapdl_18_pixbuf;
extern const GdkPixdata demdl_18_pixbuf;
extern const GdkPixdata mover_22_pixbuf;
extern const GdkPixdata ruler_18_pixbuf;
extern const GdkPixdata showpic_18_pixbuf;
extern const GdkPixdata zoom_18_pixbuf;
extern const GdkPixdata route_finder_18_pixbuf;
extern const GdkPixdata select_18_pixbuf;
extern const GdkPixdata thumbnails_pixbuf;
extern const GdkPixdata vikaggregatelayer_pixbuf;
extern const GdkPixdata vikcoordlayer_pixbuf;
extern const GdkPixdata vikdemlayer_pixbuf;
extern const GdkPixdata vikgeoreflayer_pixbuf;
extern const GdkPixdata vikgpslayer_pixbuf;
extern const GdkPixdata vikmapslayer_pixbuf;
extern const GdkPixdata viktrwlayer_pixbuf;
extern const GdkPixdata wp_camp_pixbuf;
extern const GdkPixdata wp_car_pixbuf;
extern const GdkPixdata wp_deer_pixbuf;
extern const GdkPixdata wp_flag_pixbuf;
extern const GdkPixdata wp_geocache_pixbuf;
extern const GdkPixdata wp_geocache_fnd_pixbuf;
extern const GdkPixdata wp_house_pixbuf;
extern const GdkPixdata wp_wpt_dot_pixbuf;
extern const GdkPixdata wp_dollar_pixbuf;
extern const GdkPixdata wp_golf_pixbuf;
extern const GdkPixdata wp_summit_pixbuf;
extern const GdkPixdata wp_anchor_pixbuf;
extern const GdkPixdata wp_forest_pixbuf;
extern const GdkPixdata wp_parking_pixbuf;
extern const GdkPixdata wp_sml_cty_pixbuf;
extern const GdkPixdata wp_med_cty_pixbuf;
extern const GdkPixdata wp_lrg_cty_pixbuf;
extern const GdkPixdata wp_cap_cty_pixbuf;
extern const GdkPixdata wp_bell_pixbuf;
extern const GdkPixdata wp_diamond_grn_pixbuf;
extern const GdkPixdata wp_diamond_red_pixbuf;
extern const GdkPixdata wp_dive1_pixbuf;
extern const GdkPixdata wp_dive2_pixbuf;
extern const GdkPixdata wp_fish_pixbuf;
extern const GdkPixdata wp_fuel_pixbuf;
extern const GdkPixdata wp_horn_pixbuf;
extern const GdkPixdata wp_knife_pixbuf;
extern const GdkPixdata wp_light_pixbuf;
extern const GdkPixdata wp_mug_pixbuf;
extern const GdkPixdata wp_skull_pixbuf;
extern const GdkPixdata wp_square_grn_pixbuf;
extern const GdkPixdata wp_square_red_pixbuf;
extern const GdkPixdata wp_wbuoy_pixbuf;
extern const GdkPixdata wp_wreck_pixbuf;
extern const GdkPixdata wp_null_pixbuf;
extern const GdkPixdata wp_mine_pixbuf;
extern const GdkPixdata wp_school_pixbuf;
extern const GdkPixdata wp_cemetery_pixbuf;
extern const GdkPixdata wp_church_pixbuf;
extern const GdkPixdata wp_military_pixbuf;
extern const GdkPixdata wp_mob_pixbuf;
extern const GdkPixdata wp_buoy_ambr_pixbuf;
extern const GdkPixdata wp_buoy_blck_pixbuf;
extern const GdkPixdata wp_buoy_blue_pixbuf;
extern const GdkPixdata wp_buoy_grn_pixbuf;
extern const GdkPixdata wp_buoy_grn_red_pixbuf;
extern const GdkPixdata wp_buoy_grn_wht_pixbuf;
extern const GdkPixdata wp_buoy_orng_pixbuf;
extern const GdkPixdata wp_buoy_red_pixbuf;
extern const GdkPixdata wp_buoy_red_grn_pixbuf;
extern const GdkPixdata wp_buoy_red_wht_pixbuf;
extern const GdkPixdata wp_buoy_violet_pixbuf;
extern const GdkPixdata wp_buoy_wht_pixbuf;
extern const GdkPixdata wp_buoy_wht_grn_pixbuf;
extern const GdkPixdata wp_buoy_wht_red_pixbuf;
extern const GdkPixdata wp_dot_pixbuf;
extern const GdkPixdata wp_rbcn_pixbuf;
extern const GdkPixdata wp_boat_ramp_pixbuf;
extern const GdkPixdata wp_restroom_pixbuf;
extern const GdkPixdata wp_shower_pixbuf;
extern const GdkPixdata wp_drinking_wtr_pixbuf;
extern const GdkPixdata wp_phone_pixbuf;
extern const GdkPixdata wp_1st_aid_pixbuf;
extern const GdkPixdata wp_info_pixbuf;
extern const GdkPixdata wp_park_pixbuf;
extern const GdkPixdata wp_picnic_pixbuf;
extern const GdkPixdata wp_scenic_pixbuf;
extern const GdkPixdata wp_skiing_pixbuf;
extern const GdkPixdata wp_swimming_pixbuf;
extern const GdkPixdata wp_dam_pixbuf;
extern const GdkPixdata wp_controlled_pixbuf;
extern const GdkPixdata wp_danger_pixbuf;
extern const GdkPixdata wp_restricted_pixbuf;
extern const GdkPixdata wp_ball_pixbuf;
extern const GdkPixdata wp_rv_park_pixbuf;
extern const GdkPixdata wp_bridge_pixbuf;
extern const GdkPixdata wp_building_pixbuf;
extern const GdkPixdata wp_tunnel_pixbuf;
extern const GdkPixdata wp_beach_pixbuf;
extern const GdkPixdata wp_airplane_pixbuf;
extern const GdkPixdata wp_ice_skating_pixbuf;
extern const GdkPixdata wp_1st_aid_large_pixbuf;
extern const GdkPixdata wp_airplane_large_pixbuf;
extern const GdkPixdata wp_amuse_pk_large_pixbuf;
extern const GdkPixdata wp_anchor_large_pixbuf;
extern const GdkPixdata wp_ball_large_pixbuf;
extern const GdkPixdata wp_beach_large_pixbuf;
extern const GdkPixdata wp_bell_large_pixbuf;
extern const GdkPixdata wp_bike_trail_large_pixbuf;
extern const GdkPixdata wp_block_blue_large_pixbuf;
extern const GdkPixdata wp_block_green_large_pixbuf;
extern const GdkPixdata wp_block_red_large_pixbuf;
extern const GdkPixdata wp_boat_ramp_large_pixbuf;
extern const GdkPixdata wp_bowling_large_pixbuf;
extern const GdkPixdata wp_bridge_large_pixbuf;
extern const GdkPixdata wp_building_large_pixbuf;
extern const GdkPixdata wp_buoy_ambr_large_pixbuf;
extern const GdkPixdata wp_buoy_blck_large_pixbuf;
extern const GdkPixdata wp_buoy_blue_large_pixbuf;
extern const GdkPixdata wp_buoy_grn_large_pixbuf;
extern const GdkPixdata wp_buoy_grn_red_large_pixbuf;
extern const GdkPixdata wp_buoy_grn_wht_large_pixbuf;
extern const GdkPixdata wp_buoy_orng_large_pixbuf;
extern const GdkPixdata wp_buoy_red_grn_large_pixbuf;
extern const GdkPixdata wp_buoy_red_large_pixbuf;
extern const GdkPixdata wp_buoy_red_wht_large_pixbuf;
extern const GdkPixdata wp_buoy_violet_large_pixbuf;
extern const GdkPixdata wp_buoy_wht_grn_large_pixbuf;
extern const GdkPixdata wp_buoy_wht_large_pixbuf;
extern const GdkPixdata wp_buoy_wht_red_large_pixbuf;
extern const GdkPixdata wp_camp_large_pixbuf;
extern const GdkPixdata wp_car_large_pixbuf;
extern const GdkPixdata wp_car_rental_large_pixbuf;
extern const GdkPixdata wp_car_repair_large_pixbuf;
extern const GdkPixdata wp_cemetery_large_pixbuf;
extern const GdkPixdata wp_church_large_pixbuf;
extern const GdkPixdata wp_civil_large_pixbuf;
extern const GdkPixdata wp_controlled_large_pixbuf;
extern const GdkPixdata wp_conv_store_large_pixbuf;
extern const GdkPixdata wp_crossing_large_pixbuf;
extern const GdkPixdata wp_dam_large_pixbuf;
extern const GdkPixdata wp_danger_large_pixbuf;
extern const GdkPixdata wp_deer_large_pixbuf;
extern const GdkPixdata wp_dive1_large_pixbuf;
extern const GdkPixdata wp_dive2_large_pixbuf;
extern const GdkPixdata wp_dollar_large_pixbuf;
extern const GdkPixdata wp_drinking_wtr_large_pixbuf;
extern const GdkPixdata wp_fastfood_large_pixbuf;
extern const GdkPixdata wp_fhs_facility_large_pixbuf;
extern const GdkPixdata wp_fish_large_pixbuf;
extern const GdkPixdata wp_fitness_large_pixbuf;
extern const GdkPixdata wp_flag_blue_large_pixbuf;
extern const GdkPixdata wp_flag_green_large_pixbuf;
extern const GdkPixdata wp_flag_red_large_pixbuf;
extern const GdkPixdata wp_forest_large_pixbuf;
extern const GdkPixdata wp_fuel_large_pixbuf;
extern const GdkPixdata wp_geocache_fnd_large_pixbuf;
extern const GdkPixdata wp_geocache_large_pixbuf;
extern const GdkPixdata wp_glider_large_pixbuf;
extern const GdkPixdata wp_golf_large_pixbuf;
extern const GdkPixdata wp_grnd_trans_large_pixbuf;
extern const GdkPixdata wp_horn_large_pixbuf;
extern const GdkPixdata wp_house_large_pixbuf;
extern const GdkPixdata wp_ice_skating_large_pixbuf;
extern const GdkPixdata wp_info_large_pixbuf;
extern const GdkPixdata wp_knife_large_pixbuf;
extern const GdkPixdata wp_light_large_pixbuf;
extern const GdkPixdata wp_lodging_large_pixbuf;
extern const GdkPixdata wp_lrg_cty_large_pixbuf;
extern const GdkPixdata wp_med_cty_large_pixbuf;
extern const GdkPixdata wp_mine_large_pixbuf;
extern const GdkPixdata wp_mob_large_pixbuf;
extern const GdkPixdata wp_movie_large_pixbuf;
extern const GdkPixdata wp_mug_large_pixbuf;
extern const GdkPixdata wp_museum_large_pixbuf;
extern const GdkPixdata wp_oil_field_large_pixbuf;
extern const GdkPixdata wp_parachute_large_pixbuf;
extern const GdkPixdata wp_parking_large_pixbuf;
extern const GdkPixdata wp_park_large_pixbuf;
extern const GdkPixdata wp_pharmacy_large_pixbuf;
extern const GdkPixdata wp_phone_large_pixbuf;
extern const GdkPixdata wp_picnic_large_pixbuf;
extern const GdkPixdata wp_pin_blue_large_pixbuf;
extern const GdkPixdata wp_pin_green_large_pixbuf;
extern const GdkPixdata wp_pin_red_large_pixbuf;
extern const GdkPixdata wp_pizza_large_pixbuf;
extern const GdkPixdata wp_police_large_pixbuf;
extern const GdkPixdata wp_post_ofc_large_pixbuf;
extern const GdkPixdata wp_rbcn_large_pixbuf;
extern const GdkPixdata wp_restricted_large_pixbuf;
extern const GdkPixdata wp_restroom_large_pixbuf;
extern const GdkPixdata wp_rv_park_large_pixbuf;
extern const GdkPixdata wp_scenic_large_pixbuf;
extern const GdkPixdata wp_school_large_pixbuf;
extern const GdkPixdata wp_shopping_large_pixbuf;
extern const GdkPixdata wp_short_tower_large_pixbuf;
extern const GdkPixdata wp_shower_large_pixbuf;
extern const GdkPixdata wp_skiing_large_pixbuf;
extern const GdkPixdata wp_ski_resort_large_pixbuf;
extern const GdkPixdata wp_skull_large_pixbuf;
extern const GdkPixdata wp_sml_cty_large_pixbuf;
extern const GdkPixdata wp_stadium_large_pixbuf;
extern const GdkPixdata wp_store_large_pixbuf;
extern const GdkPixdata wp_summit_large_pixbuf;
extern const GdkPixdata wp_swimming_large_pixbuf;
extern const GdkPixdata wp_tall_tower_large_pixbuf;
extern const GdkPixdata wp_theater_large_pixbuf;
extern const GdkPixdata wp_toll_booth_large_pixbuf;
extern const GdkPixdata wp_trail_head_large_pixbuf;
extern const GdkPixdata wp_truck_stop_large_pixbuf;
extern const GdkPixdata wp_tunnel_large_pixbuf;
extern const GdkPixdata wp_ultralight_large_pixbuf;
extern const GdkPixdata wp_wbuoy_large_pixbuf;
extern const GdkPixdata wp_weigh_station_large_pixbuf;
extern const GdkPixdata wp_wrecker_large_pixbuf;
extern const GdkPixdata wp_wreck_large_pixbuf;
extern const GdkPixdata wp_zoo_large_pixbuf;
extern const GdkPixdata cursor_addtr_pixbuf;
extern const GdkPixdata cursor_begintr_pixbuf;
extern const GdkPixdata cursor_edtr_pixbuf;
extern const GdkPixdata cursor_geozoom_pixbuf;
extern const GdkPixdata cursor_ruler_pixbuf;
extern const GdkPixdata cursor_addwp_pixbuf;
extern const GdkPixdata cursor_edwp_pixbuf;
extern const GdkPixdata cursor_route_finder_pixbuf;
extern const GdkPixdata cursor_showpic_pixbuf;
extern const GdkPixdata cursor_demdl_pixbuf;
extern const GdkPixdata cursor_geomove_pixbuf;
extern const GdkPixdata cursor_mapdl_pixbuf;
extern const GdkPixdata cursor_zoom_pixbuf;
